@@ -374,6 +374,12 @@ button_widget_reload_pixbuf (ButtonWidget *button)
 	gtk_widget_queue_draw (GTK_WIDGET (button));
 }
 
+static void
+button_widget_theme_changed (ButtonWidget *button)
+{
+	button_widget_reload_pixbuf (button);
+}
+
 static void
 button_widget_finalize (GObject *object)
 {
@@ -514,14 +520,40 @@ get_missing (int preffered_size)
 	return retval;
 }
 
+static GdkPixbuf *
+load_pixbuf (const char  *file,
+	     int          preffered_size,
+	     char       **str_error)
+{
+	GError    *error = NULL;
+	GdkPixbuf *retval = NULL;
+	char      *full;
+
+	full = gnome_desktop_item_find_icon (panel_icon_theme, file, preffered_size, 0);
+
+	if (full) {
+		retval = gdk_pixbuf_new_from_file (full, &error);
+		if (!retval) {
+			if (str_error)
+				*str_error = g_strdup (error ? error->message : _("none"));
+			g_error_free (error);
+		}
+		g_free (full);
+	} else if (str_error)
+		*str_error = g_strdup (_("file not found"));
+
+	return retval;
+
+
+}
+
 static GdkPixbuf *
 button_load_pixbuf (const char  *file,
 		    int          preffered_size,
 		    char       **error)
 {
 	GdkPixbuf *retval = NULL;
-	GError *gerror = NULL;
-	char *full;
+	char *tmp;
 
 	if (preffered_size <= 0)
 		preffered_size = 48;
@@ -529,20 +561,20 @@ button_load_pixbuf (const char  *file,
 	if (string_empty (file))
 		return get_missing (preffered_size);
 
-	full = gnome_desktop_item_find_icon (panel_icon_theme, file,
-					     preffered_size, 0);
-	if (full != NULL) {
-		retval = gdk_pixbuf_new_from_file (full, &gerror);
-		if (retval == NULL) {
-			*error = g_strdup (gerror ? gerror->message : _("none"));
-			g_clear_error (&gerror);
+	tmp = g_path_get_basename (file);
+	retval = load_pixbuf (tmp, preffered_size, error);
+	g_free (tmp);
+
+	if (!retval && g_path_is_absolute (file)) {
+		if (error && *error) {
+			g_free (*error);
+			*error = NULL;
 		}
-		g_free (full);
-	} else {
-		*error = g_strdup (_("file not found"));
+
+		retval = load_pixbuf (file, preffered_size, error);
 	}
 
-	if (retval == NULL)
+	if (!retval)
 		retval = get_missing (preffered_size);
 
 	return retval;
@@ -782,26 +814,15 @@ button_widget_enter_notify (GtkWidget *widget, GdkEventCrossing *event)
 static gboolean
 button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 {
-	GtkWidget *event_widget;
-	ButtonWidget *button_widget;
-	GtkButton *button;
+	gboolean in_button;
 
 	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
-	g_return_val_if_fail (event != NULL, FALSE);
 
-	event_widget = gtk_get_event_widget ((GdkEvent*) event);
-
-	button_widget = BUTTON_WIDGET (widget);
-	button = GTK_BUTTON (widget);
-
-	if ((event_widget == widget) &&
-	    (event->detail != GDK_NOTIFY_INFERIOR) &&
-	    (!button_widget->ignore_leave)) {
-		button->in_button = FALSE;
-		if (global_config.highlight_when_over) {
-			gtk_widget_queue_draw (widget);
-		}
-	}
+	in_button = GTK_BUTTON (widget)->in_button;
+	GTK_WIDGET_CLASS (parent_class)->leave_notify_event (widget, event);
+	if (in_button != GTK_BUTTON (widget)->in_button &&
+	    global_config.highlight_when_over)
+		gtk_widget_queue_draw (widget);
 
 	return FALSE;
 }
@@ -845,6 +866,10 @@ button_widget_instance_init (ButtonWidget *button)
 	button->dnd_highlight = FALSE;
 
 	button->pressed_timeout = 0;
+
+	panel_signal_connect_object_while_alive (
+			panel_icon_theme, "changed",
+			G_CALLBACK (button_widget_theme_changed), button);
 }
 
 static void
@@ -896,7 +921,7 @@ button_widget_class_init (ButtonWidgetClass *klass)
 			g_param_spec_enum ("orient",
 					   _("Orientation"),
 					   _("The ButtonWidget orientation"),
-					   PANEL_TYPE_PANEL_ORIENT,
+					   PANEL_TYPE_ORIENT,
 					   PANEL_ORIENT_UP,
 					   G_PARAM_READWRITE));
 
