@@ -585,6 +585,7 @@ browse_ok (GtkWidget *widget, GtkFileSelection *fsel)
 	fname = gtk_file_selection_get_filename (fsel);
 	if (fname != NULL) {
 		append_file (entry, fname);
+		gtk_widget_grab_focus (entry);
 	}
 	
 	gtk_widget_destroy (GTK_WIDGET (fsel));
@@ -1407,9 +1408,6 @@ unset_selected (GtkWidget *dialog)
 
         g_free (text);
         
-	if (gpixmap != NULL)
-		unset_pixmap (gpixmap);
-
         g_object_set_data (G_OBJECT (dialog), "use_list",
 			   GPOINTER_TO_INT (FALSE));
 	gtk_tree_selection_unselect_all
@@ -1566,46 +1564,59 @@ create_program_list_contents (void)
 static void
 update_contents (GtkWidget *dialog)
 {
-        GtkWidget *program_list_box = NULL;
-        gboolean show_program_list;
+	GtkWidget *program_list_box = NULL;
+	GtkWidget *entry;           
+	gboolean show_program_list;
 	const char *key;
 
 	key = panel_gconf_general_key
 		(panel_gconf_get_profile (), "show_program_list"),
 	show_program_list = panel_gconf_get_bool (key, SHOW_LIST_DEFAULT);
         
-        if (show_program_list) {
-                program_list_box = g_object_get_data (G_OBJECT (dialog), "program_list_box");
+	if (show_program_list) {
+		program_list_box = g_object_get_data (G_OBJECT (dialog),
+						      "program_list_box");
 
-                if (program_list_box && program_list_box->parent == NULL) {
+		if (program_list_box && program_list_box->parent == NULL) {
 			GtkWidget *list;
-			
+			GtkTreeSelection *selection;
+			GtkTreeModel *model;
+			GtkTreeIter iter;
+
 			gtk_window_resize (GTK_WINDOW (dialog), 100, 300);
 			gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
-			
-                        gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
-                                            program_list_box,
-                                            TRUE, TRUE, GNOME_PAD_SMALL);
-                
 
-                        gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (dialog)->vbox));
+			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+					    program_list_box,
+					    TRUE, TRUE, GNOME_PAD_SMALL);
+
+			gtk_widget_show_all (GTK_WIDGET (GTK_DIALOG (dialog)->vbox));
 
 			list = g_object_get_data (G_OBJECT (dialog), "program_list");
-			gtk_widget_grab_focus (list);
-		}
-        } else {    
-		GtkWidget *entry;           
+			selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
 
-                program_list_box = g_object_get_data (G_OBJECT (dialog), "program_list_box");
+			if (gtk_tree_view_get_model (GTK_TREE_VIEW (list)) &&
+			    !gtk_tree_selection_get_selected (selection,&model, &iter)) {
+			
+				entry = g_object_get_data (G_OBJECT (dialog), "entry");
+				gtk_widget_grab_focus (entry);
+			} else
+				gtk_widget_grab_focus (list);
+		}
+	} else {    
+
+		program_list_box = g_object_get_data (G_OBJECT (dialog),
+						      "program_list_box");
                 
-                if (program_list_box && program_list_box->parent != NULL) {
-                        gtk_container_remove (GTK_CONTAINER (program_list_box->parent), program_list_box);
+		if (program_list_box && program_list_box->parent != NULL) {
+			gtk_container_remove (GTK_CONTAINER (program_list_box->parent),
+					      program_list_box);
 			gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 		}
 
 		entry = g_object_get_data (G_OBJECT (dialog), "entry");
-                gtk_widget_grab_focus (entry);
-        }
+		gtk_widget_grab_focus (entry);
+	}
 }
 
 static void
@@ -1699,11 +1710,13 @@ show_run_dialog (GdkScreen *screen)
 			g_idle_add_full (G_PRIORITY_LOW, add_items_idle,
 			 		 w, NULL);
 
-		gtk_widget_grab_focus (w);
-	} else {
-		w = g_object_get_data (G_OBJECT (run_dialog), "entry");
-		gtk_widget_grab_focus (w);
-	}
+	} 
+
+	/* None of the apps in the list are selected when the dialog is launched.
+	   Hence entry can be safely grabbed
+	*/
+	w = g_object_get_data (G_OBJECT (run_dialog), "entry");
+	gtk_widget_grab_focus (w);
 	
 	gtk_widget_show_all (run_dialog);
 }
