@@ -51,9 +51,6 @@ struct _PanelAppletFrame{
 
 struct _PanelAppletFrameClass {
         GtkEventBoxClass          event_box_class;
-
-	void (* move_focus_out_of_applet) (PanelAppletFrame *frame,
-					   GtkDirectionType  direction);
 };
 
 GType      panel_applet_frame_get_type  (void) G_GNUC_CONST;
@@ -72,7 +69,8 @@ void       panel_applet_frame_set_info  (PanelAppletFrame *frame,
 					
 void       panel_applet_frame_load      (const gchar *iid,
 					 PanelWidget *panel,
-					 gint         pos,
+					 int          position,
+					 gboolean     exactpos,
 					 const char  *gconf_key);
 
 void       panel_applet_frame_load_applets  (void);
@@ -83,8 +81,8 @@ void       panel_applet_frame_change_orient (PanelAppletFrame *frame,
 void       panel_applet_frame_change_size   (PanelAppletFrame *frame,
 					     PanelSize         size);
 
-void       panel_applet_frame_change_background (PanelAppletFrame *frame,
-						 PanelBackType     type);
+void       panel_applet_frame_change_background (PanelAppletFrame    *frame,
+						 PanelBackgroundType  type);
 
 void       panel_applet_frame_get_expand_flags  (PanelAppletFrame *frame,
 						 gboolean         *expand_major,
@@ -94,16 +92,16 @@ void       panel_applet_frame_save_to_gconf     (PanelAppletFrame *frame,
 						 const char       *gconf_key);
 
 void       panel_applet_frame_load_from_gconf   (PanelWidget *panel_widget,
-						 gint         position,
+						 int          position,
 						 const char  *gconf_key);
 
-void       panel_applet_frame_set_clean_remove	(PanelAppletFrame *frame,
-						 gboolean          clean_remove);
-gboolean   panel_applet_frame_get_clean_remove	(PanelAppletFrame *frame);
+int        panel_applet_frame_get_size_hints    (PanelAppletFrame  *frame,
+						 int              **size_hints);
 
+void       panel_applet_frame_set_panel         (PanelAppletFrame *frame,
+						 PanelWidget *panel);
 
-int *      panel_applet_frame_get_size_hints    (PanelAppletFrame *frame,
-						 int              *n_elements);
+PanelWidget    *panel_applet_frame_get_panel    (PanelAppletFrame *frame);
 
 G_END_DECLS
 
